# whichimg
![travis-badge](https://travis-ci.org/Madoshakalaka/whichimg.svg?branch=master)

blazing fast template matching when possible images are all known

## Showcase

<!--You picture won't show on pypi if you use relative path.-->
<!--If you want to add any image, please add the image to readme_assets folder and add the filename as below-->
<!--![some show case picture](https://raw.githubusercontent.com/Madoshakalaka/whichimg/master/readme_assets/showcasePicture.png)-->


## How to Use


`pip install whichimg`

<!--

add some help here 

```python

```

-->



Pip creates command line executable entry point by default

You should be able to run shell command `$whichimg` anywhere.

<!--
add some command help here


- `$ whichimg -i filename`
    - output: `hello world`

-->

- `$ whichimg -h` for more help

